==> parcel-bundler-vue-1.6.3.tgz: package/lib/utils/PromiseQueue.js <==
"use strict";

var _regenerator = require("babel-runtime/regenerator");

var _regenerator2 = _interopRequireDefault(_regenerator);

var _toConsumableArray2 = require("babel-runtime/helpers/toConsumableArray");

var _toConsumableArray3 = _interopRequireDefault(_toConsumableArray2);

var _asyncToGenerator2 = require("babel-runtime/helpers/asyncToGenerator");

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _promise = require("babel-runtime/core-js/promise");

var _promise2 = _interopRequireDefault(_promise);

var _set = require("babel-runtime/core-js/set");

var _set2 = _interopRequireDefault(_set);

var _classCallCheck2 = require("babel-runtime/helpers/classCallCheck");

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require("babel-runtime/helpers/createClass");

var _createClass3 = _interopRequireDefault(_createClass2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var PromiseQueue = function () {
  function PromiseQueue(callback) {
    (0, _classCallCheck3.default)(this, PromiseQueue);

    this.process = callback;
    this.queue = [];
    this.processing = new _set2.default();
    this.processed = new _set2.default();
    this.runPromise = null;
    this.resolve = null;
    this.reject = null;
  }

  (0, _createClass3.default)(PromiseQueue, [{
    key: "add",
    value: function add(job) {
      if (this.processing.has(job)) {
        return;
      }

      for (var _len = arguments.length, args = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
        args[_key - 1] = arguments[_key];
      }

      if (this.runPromise) {
        this._runJob(job, args);
      } else {
        this.queue.push([job, args]);
      }

      this.processing.add(job);
    }
  }, {
    key: "run",
    value: function run() {
      var _this = this;

      if (this.runPromise) {
        return this.runPromise;
      }

      var runPromise = new _promise2.default(function (resolve, reject) {
        _this.resolve = resolve;
        _this.reject = reject;
      });

      this.runPromise = runPromise;
      this._next();

      return runPromise;
    }
  }, {
    key: "_runJob",
    value: function () {
      var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee(job, args) {
        return _regenerator2.default.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                _context.prev = 0;
                _context.next = 3;
                return this.process.apply(this, [job].concat((0, _toConsumableArray3.default)(args)));

              case 3:
                this.processing.delete(job);
                this.processed.add(job);
                this._next();
                _context.next = 13;
                break;

              case 8:
                _context.prev = 8;
                _context.t0 = _context["catch"](0);

                this.queue.push([job, args]);
                this.reject(_context.t0);
                this._reset();

              case 13:
              case "end":
                return _context.stop();
            }
          }
        }, _callee, this, [[0, 8]]);
      }));

      function _runJob(_x, _x2) {
        return _ref.apply(this, arguments);
      }

      return _runJob;
    }()
  }, {
    key: "_next",
    value: function _next() {
      if (!this.runPromise) {
        return;
      }

      if (this.queue.length > 0) {
        while (this.queue.length > 0) {
          this._runJob.apply(this, (0, _toConsumableArray3.default)(this.queue.shift()));
        }
      } else if (this.processing.size === 0) {
        this.resolve(this.processed);
        this._reset();
      }
    }
  }, {
    key: "_reset",
    value: function _reset() {
      this.processed = new _set2.default();
      this.runPromise = null;
      this.resolve = null;
      this.reject = null;
    }
  }, {
    key: "empty",
    get: function get() {
      return this.queue.length <= 0;
    }
  }]);
  return PromiseQueue;
}();

module.exports = PromiseQueue;

==> parcel-bundler-vue-2.0.0.tgz: package/lib/utils/PromiseQueue.js <==
"use strict";

var _regenerator = require("babel-runtime/regenerator");

var _regenerator2 = _interopRequireDefault(_regenerator);

var _toConsumableArray2 = require("babel-runtime/helpers/toConsumableArray");

var _toConsumableArray3 = _interopRequireDefault(_toConsumableArray2);

var _asyncToGenerator2 = require("babel-runtime/helpers/asyncToGenerator");

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _promise = require("babel-runtime/core-js/promise");

var _promise2 = _interopRequireDefault(_promise);

var _set = require("babel-runtime/core-js/set");

var _set2 = _interopRequireDefault(_set);

var _classCallCheck2 = require("babel-runtime/helpers/classCallCheck");

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require("babel-runtime/helpers/createClass");

var _createClass3 = _interopRequireDefault(_createClass2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var PromiseQueue = function () {
  function PromiseQueue(callback) {
    (0, _classCallCheck3.default)(this, PromiseQueue);

    this.process = callback;
    this.queue = [];
    this.processing = new _set2.default();
    this.processed = new _set2.default();
    this.runPromise = null;
    this.resolve = null;
    this.reject = null;
  }

  (0, _createClass3.default)(PromiseQueue, [{
    key: "add",
    value: function add(job) {
      if (this.processing.has(job)) {
        return;
      }

      for (var _len = arguments.length, args = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
        args[_key - 1] = arguments[_key];
      }

      if (this.runPromise) {
        this._runJob(job, args);
      } else {
        this.queue.push([job, args]);
      }

      this.processing.add(job);
    }
  }, {
    key: "run",
    value: function run() {
      var _this = this;

      if (this.runPromise) {
        return this.runPromise;
      }

      this.runPromise = new _promise2.default(function (resolve, reject) {
        _this.resolve = resolve;
        _this.reject = reject;
      });

      this._next();
      return this.runPromise;
    }
  }, {
    key: "_runJob",
    value: function () {
      var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee(job, args) {
        return _regenerator2.default.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                _context.prev = 0;
                _context.next = 3;
                return this.process.apply(this, [job].concat((0, _toConsumableArray3.default)(args)));

              case 3:
                this.processing.delete(job);
                this.processed.add(job);
                this._next();
                _context.next = 13;
                break;

              case 8:
                _context.prev = 8;
                _context.t0 = _context["catch"](0);

                this.queue.push([job, args]);
                this.reject(_context.t0);
                this._reset();

              case 13:
              case "end":
                return _context.stop();
            }
          }
        }, _callee, this, [[0, 8]]);
      }));

      function _runJob(_x, _x2) {
        return _ref.apply(this, arguments);
      }

      return _runJob;
    }()
  }, {
    key: "_next",
    value: function _next() {
      if (!this.runPromise) {
        return;
      }

      if (this.queue.length > 0) {
        while (this.queue.length > 0) {
          this._runJob.apply(this, (0, _toConsumableArray3.default)(this.queue.shift()));
        }
      } else if (this.processing.size === 0) {
        this.resolve(this.processed);
        this._reset();
      }
    }
  }, {
    key: "_reset",
    value: function _reset() {
      this.processed = new _set2.default();
      this.runPromise = null;
      this.resolve = null;
      this.reject = null;
    }
  }, {
    key: "empty",
    get: function get() {
      return this.queue.length <= 0;
    }
  }]);
  return PromiseQueue;
}();

module.exports = PromiseQueue;
